@@ -1,3 +1,4 @@
+from __future__ import print_function
 from os.path import abspath, join, dirname
 from relatorio import Report
 
@@ -6,9 +7,9 @@ from common import inv
 
 # PDF
 if __name__ == '__main__':
-    print "generating output_basic.pdf... ",
+    print("generating output_basic.pdf... ", end='')
     report = Report(abspath(join(dirname(__file__), 'basic.tex')),
         'application/pdf')
     content = report(o=inv).render().getvalue()
     open(join(dirname(__file__), 'output_basic.pdf'), 'wb').write(content)
-    print "done"
+    print("done")
